pub struct Callback {
pub available_payloads: Option<Vec<String>>,
pub method: Option<String>,
pub name: Option<String>,
pub waiters: Option<i64>,
}Expand description
An instance of a Callback created by an execution.
This type is not used in any activity, and only used as part of another schema.
Fields
available_payloads: Option<Vec<String>>Output only. The payloads received by the callback that have not been processed by a waiting execution step.
method: Option<String>Output only. The method accepted by the callback. For example: GET, POST, PUT.
name: Option<String>Output only. The resource name of the callback. Format: projects/{project}/locations/{location}/workflows/{workflow}/executions/{execution}/callback/{callback}
waiters: Option<i64>Output only. Number of execution steps waiting on this callback.