pub struct Error {
pub context: Option<String>,
pub payload: Option<String>,
pub stack_trace: Option<StackTrace>,
}Expand description
Error describes why the execution was abnormally terminated.
This type is not used in any activity, and only used as part of another schema.
Fields
context: Option<String>Human-readable stack trace string.
payload: Option<String>Error message and data returned represented as a JSON string.
stack_trace: Option<StackTrace>Stack trace with detailed information of where error was generated.