pub struct Step {
pub routine: Option<String>,
pub step: Option<String>,
}Expand description
Represents a step of the workflow this execution is running.
This type is not used in any activity, and only used as part of another schema.
Fields
routine: Option<String>Name of a routine within the workflow.
step: Option<String>Name of a step within the routine.