Module api

Module api 

Structs

Callback
An instance of a Callback created by an execution.
CancelExecutionRequest
Request for the CancelExecution method.
DeleteExecutionHistoryRequest
Request for the DeleteExecutionHistory method.
Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
Error
Error describes why the execution was abnormally terminated.
Exception
Exception describes why the step entry failed.
Execution
A running instance of a Workflow.
ExportDataResponse
Response for the ExportData method.
ListCallbacksResponse
RPC response object for the ListCallbacks method.
ListExecutionsResponse
Response for the ListExecutions method.
ListStepEntriesResponse
Response message for ExecutionHistory.ListStepEntries.
NavigationInfo
NavigationInfo describes what steps if any come before or after this step, or what steps are parents or children of this step.
Position
Position contains source position information about the stack trace element such as line number, column number and length of the code block in bytes.
ProjectLocationWorkflowExecutionCallbackListCall
Returns a list of active callbacks that belong to the execution with the given name. The returned callbacks are ordered by callback ID.
ProjectLocationWorkflowExecutionCancelCall
Cancels an execution of the given name.
ProjectLocationWorkflowExecutionCreateCall
Creates a new execution using the latest revision of the given workflow. For more information, see Execute a workflow.
ProjectLocationWorkflowExecutionDeleteExecutionHistoryCall
Deletes all step entries for an execution.
ProjectLocationWorkflowExecutionExportDataCall
Returns all metadata stored about an execution, excluding most data that is already accessible using other API methods.
ProjectLocationWorkflowExecutionGetCall
Returns an execution of the given name.
ProjectLocationWorkflowExecutionListCall
Returns a list of executions which belong to the workflow with the given name. The method returns executions of all workflow revisions. Returned executions are ordered by their start time (newest first).
ProjectLocationWorkflowExecutionStepEntryGetCall
Gets a step entry.
ProjectLocationWorkflowExecutionStepEntryListCall
Lists step entries for the corresponding workflow execution. Returned entries are ordered by their create_time.
ProjectLocationWorkflowTriggerPubsubExecutionCall
Triggers a new execution using the latest revision of the given workflow by a Pub/Sub push notification.
ProjectMethods
A builder providing access to all methods supported on project resources. It is not used directly, but through the WorkflowExecutions hub.
PubsubMessage
A message that is published by publishers and consumed by subscribers. The message must contain either a non-empty data field or at least one attribute. Note that client libraries represent this object differently depending on the language. See the corresponding client library documentation for more information. See [quotas and limits] (https://cloud.google.com/pubsub/quotas) for more information about message limits.
StackTrace
A collection of stack elements (frames) where an error occurred.
StackTraceElement
A single stack element (frame) where an error occurred.
StateError
Describes an error related to the current state of the Execution resource.
Status
Represents the current status of this execution.
Step
Represents a step of the workflow this execution is running.
StepEntry
An StepEntry contains debugging information for a step transition in a workflow execution.
StepEntryMetadata
StepEntryMetadata contains metadata information about this step.
TriggerPubsubExecutionRequest
Request for the TriggerPubsubExecution method.
VariableData
VariableData contains the variable data for this step.
WorkflowExecutions
Central instance to access all WorkflowExecutions related resource activities

Enums

Scope
Identifies the an OAuth2 authorization scope. A scope is needed when requesting an authorization token.