pub struct StepEntry {
pub create_time: Option<DateTime<Utc>>,
pub entry_id: Option<i64>,
pub exception: Option<Exception>,
pub name: Option<String>,
pub navigation_info: Option<NavigationInfo>,
pub routine: Option<String>,
pub state: Option<String>,
pub step: Option<String>,
pub step_entry_metadata: Option<StepEntryMetadata>,
pub step_type: Option<String>,
pub update_time: Option<DateTime<Utc>>,
pub variable_data: Option<VariableData>,
}Expand description
An StepEntry contains debugging information for a step transition in a workflow execution.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
create_time: Option<DateTime<Utc>>Output only. The creation time of the step entry.
entry_id: Option<i64>Output only. The numeric ID of this step entry, used for navigation.
exception: Option<Exception>Output only. The exception thrown by the step entry.
name: Option<String>Output only. The full resource name of the step entry. Each step entry has a unique entry ID, which is a monotonically increasing counter. Step entry names have the format: projects/{project}/locations/{location}/workflows/{workflow}/executions/{execution}/stepEntries/{step_entry}.
Output only. The NavigationInfo associated with this step.
routine: Option<String>Output only. The name of the routine this step entry belongs to. A routine name is the subworkflow name defined in the YAML source code. The top level routine name is main.
state: Option<String>Output only. The state of the step entry.
step: Option<String>Output only. The name of the step this step entry belongs to.
step_entry_metadata: Option<StepEntryMetadata>Output only. The StepEntryMetadata associated with this step.
step_type: Option<String>Output only. The type of the step this step entry belongs to.
update_time: Option<DateTime<Utc>>Output only. The most recently updated time of the step entry.
variable_data: Option<VariableData>Output only. The VariableData associated with this step.